@@ -18,4 +18,14 @@ thisRequires <- function(pkgname){
 }
 
 # defining global variables more centrally
-utils::globalVariables(c(".data", "obs"))
\ No newline at end of file
+utils::globalVariables(c(".data", "obs"))
+
+# Suppress R CMD check note
+# Namespace in Imports field not imported from: PKG
+#   All declared Imports should be used.
+#' @importFrom autograph ag_base
+ignore_unused_imports <- function() {
+  # This function exists only to reference autograph::ag_base and suppress R CMD check notes about unused imports.
+  autograph::ag_base
+  NULL
+}
\ No newline at end of file
